# Reference

Technical reference material including APIs and release notes.

```{toctree}
:maxdepth: 1
:glob:

API <api/api>
genindex
Release Notes <https://github.com/DiamondLightSource/aioca/releases>
```
